@@ -8,8 +8,7 @@ use Laminas\Stdlib\ArrayObject;
 
 final class CustomArrayObject extends ArrayObject
 {
-    /** @var bool */
-    protected $isImmutable = true;
+    protected bool $isImmutable = true;
 
     public function isImmutable(): bool
     {
